=======
History
=======


0.5.4 (2020-10-20)
------------------

* Send a newline when replying to postfiX

0.5.3 (2020-10-20)
------------------

* Last version that supports Python 2.7
* Fixes issue with renamed module that rendered 0.5.2 non-working
* Pins dnspython < 2.0.0 since 2.0.0 does not support Python 2.7

0.4.1 (2017-05-13)
------------------

* Fix "[Errno 98] Address already in use" error when restarting the daemon

0.4.0 (2017-03-20)
------------------

* Beta release on PyPI.

0.1.0 (2017-03-14)
------------------

* First release on PyPI.
